Struct tk_bufstream::IoBuf
[−]
[src]
pub struct IoBuf<S: Io> {
pub in_buf: Buf,
pub out_buf: Buf,
// some fields omitted
}A wrapper for full-duplex stream
Fields
in_buf: Buf
out_buf: Buf
Methods
impl<S: Io> IoBuf<S>[src]
Main trait of a stream (meaning socket) with input and output buffers
This is ought to be similar to tokio_core::Io but with buffers
fn new(sock: S) -> IoBuf<S>
Create a new IoBuf object with empty buffers
fn read(&mut self) -> Result<usize, Error>
Read a chunk of data into a buffer
The data just read can then be found in self.in_buf.
This method does just one read. Because you are ought to try parse request after every read rather than reading a lot of the data in memory.
This method returns 0 when no bytes are read, both when WouldBlock
occurred and when connection has been closed. You may then use
self.done() to distinguish from these conditions.
fn flush(&mut self) -> Result<(), Error>
Write data in the output buffer to actual stream
You should put the data to be sent into self.out_buf before flush
fn done(&self) -> bool
Returns true when connection is closed by peer
fn flushed(self) -> Flushed<S>
Returns a future which resolves to this stream when output buffer is flushed